# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RefundRequestEWalletAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "bank_branch": "str",
        "bank_code": "str",
        "id": "str",
        "type": "str",
    }

    attribute_map = {
        "bank_branch": "bank_branch",
        "bank_code": "bank_code",
        "id": "id",
        "type": "type",
    }

    def __init__(
        self, bank_branch=None, bank_code=None, id=None, type=None
    ):  # noqa: E501
        """RefundRequestEWalletAccount - a model defined in Swagger"""  # noqa: E501

        self._bank_branch = None
        self._bank_code = None
        self._id = None
        self._type = None
        self.discriminator = None

        if bank_branch is not None:
            self.bank_branch = bank_branch
        if bank_code is not None:
            self.bank_code = bank_code
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type

    @property
    def bank_branch(self):
        """Gets the bank_branch of this RefundRequestEWalletAccount.  # noqa: E501

        Customer bank branch number (name). Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL.   # noqa: E501

        :return: The bank_branch of this RefundRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._bank_branch

    @bank_branch.setter
    def bank_branch(self, bank_branch):
        """Sets the bank_branch of this RefundRequestEWalletAccount.

        Customer bank branch number (name). Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL.   # noqa: E501

        :param bank_branch: The bank_branch of this RefundRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if bank_branch is not None and len(bank_branch) > 45:
            raise ValueError(
                "Invalid value for `bank_branch`, length must be less than or equal to `45`"
            )  # noqa: E501
        if bank_branch is not None and len(bank_branch) < 0:
            raise ValueError(
                "Invalid value for `bank_branch`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._bank_branch = bank_branch

    @property
    def bank_code(self):
        """Gets the bank_code of this RefundRequestEWalletAccount.  # noqa: E501

        Customer bank code. Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL.  # noqa: E501

        :return: The bank_code of this RefundRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._bank_code

    @bank_code.setter
    def bank_code(self, bank_code):
        """Sets the bank_code of this RefundRequestEWalletAccount.

        Customer bank code. Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL.  # noqa: E501

        :param bank_code: The bank_code of this RefundRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if bank_code is not None and len(bank_code) > 10:
            raise ValueError(
                "Invalid value for `bank_code`, length must be less than or equal to `10`"
            )  # noqa: E501
        if bank_code is not None and len(bank_code) < 0:
            raise ValueError(
                "Invalid value for `bank_code`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._bank_code = bank_code

    @property
    def id(self):
        """Gets the id of this RefundRequestEWalletAccount.  # noqa: E501

        For BOLETO, LOTERICA, DEPOSITEXPRESSBRL: Customer bank account number.  # noqa: E501

        :return: The id of this RefundRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RefundRequestEWalletAccount.

        For BOLETO, LOTERICA, DEPOSITEXPRESSBRL: Customer bank account number.  # noqa: E501

        :param id: The id of this RefundRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if id is not None and len(id) > 256:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `256`"
            )  # noqa: E501
        if id is not None and len(id) < 1:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._id = id

    @property
    def type(self):
        """Gets the type of this RefundRequestEWalletAccount.  # noqa: E501

        Customer account type. Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL. 1 - Savings account, 2 - Checking account  # noqa: E501

        :return: The type of this RefundRequestEWalletAccount.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RefundRequestEWalletAccount.

        Customer account type. Mandatory for BOLETO, LOTERICA, DEPOSITEXPRESSBRL. 1 - Savings account, 2 - Checking account  # noqa: E501

        :param type: The type of this RefundRequestEWalletAccount.  # noqa: E501
        :type: str
        """
        if type is not None and len(type) > 1:
            raise ValueError(
                "Invalid value for `type`, length must be less than or equal to `1`"
            )  # noqa: E501
        if type is not None and len(type) < 0:
            raise ValueError(
                "Invalid value for `type`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RefundRequestEWalletAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundRequestEWalletAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.filing_recurring_data import FilingRecurringData  # noqa: F401,E501
from cardpay.model.filing_request_merchant_order import (
    FilingRequestMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.filing_request_subscription_data import (
    FilingRequestSubscriptionData,
)  # noqa: F401,E501
from cardpay.model.payment_request_card_account import (
    PaymentRequestCardAccount,
)  # noqa: F401,E501
from cardpay.model.recurring_customer import RecurringCustomer  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.return_urls import ReturnUrls  # noqa: F401,E501
from cardpay.model.three_d_secure_data import ThreeDSecureData  # noqa: F401,E501


class FilingRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "card_account": "PaymentRequestCardAccount",
        "customer": "RecurringCustomer",
        "merchant_order": "FilingRequestMerchantOrder",
        "payment_method": "str",
        "recurring_data": "FilingRecurringData",
        "return_urls": "ReturnUrls",
        "subscription_data": "FilingRequestSubscriptionData",
        "three_d_secure": "ThreeDSecureData",
    }

    attribute_map = {
        "request": "request",
        "card_account": "card_account",
        "customer": "customer",
        "merchant_order": "merchant_order",
        "payment_method": "payment_method",
        "recurring_data": "recurring_data",
        "return_urls": "return_urls",
        "subscription_data": "subscription_data",
        "three_d_secure": "three_d_secure",
    }

    def __init__(
        self,
        request=None,
        card_account=None,
        customer=None,
        merchant_order=None,
        payment_method=None,
        recurring_data=None,
        return_urls=None,
        subscription_data=None,
        three_d_secure=None,
    ):  # noqa: E501
        """FilingRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._card_account = None
        self._customer = None
        self._merchant_order = None
        self._payment_method = None
        self._recurring_data = None
        self._return_urls = None
        self._subscription_data = None
        self._three_d_secure = None
        self.discriminator = None

        self.request = request
        if card_account is not None:
            self.card_account = card_account
        if customer is not None:
            self.customer = customer
        if merchant_order is not None:
            self.merchant_order = merchant_order
        self.payment_method = payment_method
        if recurring_data is not None:
            self.recurring_data = recurring_data
        if return_urls is not None:
            self.return_urls = return_urls
        if subscription_data is not None:
            self.subscription_data = subscription_data
        if three_d_secure is not None:
            self.three_d_secure = three_d_secure

    @property
    def request(self):
        """Gets the request of this FilingRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this FilingRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this FilingRequest.

        Request  # noqa: E501

        :param request: The request of this FilingRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def card_account(self):
        """Gets the card_account of this FilingRequest.  # noqa: E501

        Card account  # noqa: E501

        :return: The card_account of this FilingRequest.  # noqa: E501
        :rtype: PaymentRequestCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this FilingRequest.

        Card account  # noqa: E501

        :param card_account: The card_account of this FilingRequest.  # noqa: E501
        :type: PaymentRequestCardAccount
        """

        self._card_account = card_account

    @property
    def customer(self):
        """Gets the customer of this FilingRequest.  # noqa: E501

        Customer  # noqa: E501

        :return: The customer of this FilingRequest.  # noqa: E501
        :rtype: RecurringCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this FilingRequest.

        Customer  # noqa: E501

        :param customer: The customer of this FilingRequest.  # noqa: E501
        :type: RecurringCustomer
        """

        self._customer = customer

    @property
    def merchant_order(self):
        """Gets the merchant_order of this FilingRequest.  # noqa: E501

        Merchant order  # noqa: E501

        :return: The merchant_order of this FilingRequest.  # noqa: E501
        :rtype: FilingRequestMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this FilingRequest.

        Merchant order  # noqa: E501

        :param merchant_order: The merchant_order of this FilingRequest.  # noqa: E501
        :type: FilingRequestMerchantOrder
        """

        self._merchant_order = merchant_order

    @property
    def payment_method(self):
        """Gets the payment_method of this FilingRequest.  # noqa: E501

        Used payment method type name from payment methods list\"  # noqa: E501

        :return: The payment_method of this FilingRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this FilingRequest.

        Used payment method type name from payment methods list\"  # noqa: E501

        :param payment_method: The payment_method of this FilingRequest.  # noqa: E501
        :type: str
        """
        if payment_method is None:
            raise ValueError(
                "Invalid value for `payment_method`, must not be `None`"
            )  # noqa: E501
        if payment_method is not None and len(payment_method) > 100:
            raise ValueError(
                "Invalid value for `payment_method`, length must be less than or equal to `100`"
            )  # noqa: E501
        if payment_method is not None and len(payment_method) < 1:
            raise ValueError(
                "Invalid value for `payment_method`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._payment_method = payment_method

    @property
    def recurring_data(self):
        """Gets the recurring_data of this FilingRequest.  # noqa: E501

        Recurring data  # noqa: E501

        :return: The recurring_data of this FilingRequest.  # noqa: E501
        :rtype: FilingRecurringData
        """
        return self._recurring_data

    @recurring_data.setter
    def recurring_data(self, recurring_data):
        """Sets the recurring_data of this FilingRequest.

        Recurring data  # noqa: E501

        :param recurring_data: The recurring_data of this FilingRequest.  # noqa: E501
        :type: FilingRecurringData
        """

        self._recurring_data = recurring_data

    @property
    def return_urls(self):
        """Gets the return_urls of this FilingRequest.  # noqa: E501

        Return URLs  # noqa: E501

        :return: The return_urls of this FilingRequest.  # noqa: E501
        :rtype: ReturnUrls
        """
        return self._return_urls

    @return_urls.setter
    def return_urls(self, return_urls):
        """Sets the return_urls of this FilingRequest.

        Return URLs  # noqa: E501

        :param return_urls: The return_urls of this FilingRequest.  # noqa: E501
        :type: ReturnUrls
        """

        self._return_urls = return_urls

    @property
    def subscription_data(self):
        """Gets the subscription_data of this FilingRequest.  # noqa: E501

        Subscription data  # noqa: E501

        :return: The subscription_data of this FilingRequest.  # noqa: E501
        :rtype: FilingRequestSubscriptionData
        """
        return self._subscription_data

    @subscription_data.setter
    def subscription_data(self, subscription_data):
        """Sets the subscription_data of this FilingRequest.

        Subscription data  # noqa: E501

        :param subscription_data: The subscription_data of this FilingRequest.  # noqa: E501
        :type: FilingRequestSubscriptionData
        """

        self._subscription_data = subscription_data

    @property
    def three_d_secure(self):
        """Gets the three_d_secure of this FilingRequest.  # noqa: E501


        :return: The three_d_secure of this FilingRequest.  # noqa: E501
        :rtype: ThreeDSecureData
        """
        return self._three_d_secure

    @three_d_secure.setter
    def three_d_secure(self, three_d_secure):
        """Sets the three_d_secure of this FilingRequest.


        :param three_d_secure: The three_d_secure of this FilingRequest.  # noqa: E501
        :type: ThreeDSecureData
        """

        self._three_d_secure = three_d_secure

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(FilingRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RecurringPlanRequestPlanData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "interval": "int",
        "name": "str",
        "period": "str",
        "retries": "int",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "interval": "interval",
        "name": "name",
        "period": "period",
        "retries": "retries",
    }

    def __init__(
        self,
        amount=None,
        currency=None,
        interval=None,
        name=None,
        period=None,
        retries=None,
    ):  # noqa: E501
        """RecurringPlanRequestPlanData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._interval = None
        self._name = None
        self._period = None
        self._retries = None
        self.discriminator = None

        self.amount = amount
        self.currency = currency
        self.interval = interval
        self.name = name
        self.period = period
        if retries is not None:
            self.retries = retries

    @property
    def amount(self):
        """Gets the amount of this RecurringPlanRequestPlanData.  # noqa: E501

        The amount charged per period defined in plan in selected currency with dot as a decimal separator, limit is defined by payment method and transaction details.  # noqa: E501

        :return: The amount of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RecurringPlanRequestPlanData.

        The amount charged per period defined in plan in selected currency with dot as a decimal separator, limit is defined by payment method and transaction details.  # noqa: E501

        :param amount: The amount of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this RecurringPlanRequestPlanData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of plan  # noqa: E501

        :return: The currency of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this RecurringPlanRequestPlanData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of plan  # noqa: E501

        :param currency: The currency of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def interval(self):
        """Gets the interval of this RecurringPlanRequestPlanData.  # noqa: E501

        The frequency interval of period, can be 1-365 depending on selected period value. Maximum value of period + interval can be 365 days / 52 weeks / 12 months / 1 year. From 1 to 60 minutes - for **sandbox** environment and testing purpose only  # noqa: E501

        :return: The interval of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this RecurringPlanRequestPlanData.

        The frequency interval of period, can be 1-365 depending on selected period value. Maximum value of period + interval can be 365 days / 52 weeks / 12 months / 1 year. From 1 to 60 minutes - for **sandbox** environment and testing purpose only  # noqa: E501

        :param interval: The interval of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: int
        """
        if interval is None:
            raise ValueError(
                "Invalid value for `interval`, must not be `None`"
            )  # noqa: E501
        if interval is not None and interval < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for `interval`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._interval = interval

    @property
    def name(self):
        """Gets the name of this RecurringPlanRequestPlanData.  # noqa: E501

        Plan name  # noqa: E501

        :return: The name of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RecurringPlanRequestPlanData.

        Plan name  # noqa: E501

        :param name: The name of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501
        if name is not None and len(name) > 25:
            raise ValueError(
                "Invalid value for `name`, length must be less than or equal to `25`"
            )  # noqa: E501
        if name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._name = name

    class Period(object):
        MINUTE = "minute"
        DAY = "day"
        WEEK = "week"
        MONTH = "month"
        YEAR = "year"

    @property
    def period(self):
        """Gets the period of this RecurringPlanRequestPlanData.  # noqa: E501

        Initial period of recurring, can be `day`, `week`, `month`, `year`. Additional period: `minute` - for **sandbox** and testing purpose only.  # noqa: E501

        :return: The period of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this RecurringPlanRequestPlanData.

        Initial period of recurring, can be `day`, `week`, `month`, `year`. Additional period: `minute` - for **sandbox** and testing purpose only.  # noqa: E501

        :param period: The period of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: str
        """
        if period is None:
            raise ValueError(
                "Invalid value for `period`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["minute", "day", "week", "month", "year"]  # noqa: E501
        if period not in allowed_values:
            raise ValueError(
                "Invalid value for `period` ({0}), must be one of {1}".format(  # noqa: E501
                    period, allowed_values
                )
            )

        self._period = period

    @property
    def retries(self):
        """Gets the retries of this RecurringPlanRequestPlanData.  # noqa: E501

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :return: The retries of this RecurringPlanRequestPlanData.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this RecurringPlanRequestPlanData.

        Number of daily basis retry attempts in case of payment has not been captured successfully, from 1 to 15 attempts can be specified.  # noqa: E501

        :param retries: The retries of this RecurringPlanRequestPlanData.  # noqa: E501
        :type: int
        """
        if retries is not None and retries > 15:  # noqa: E501
            raise ValueError(
                "Invalid value for `retries`, must be a value less than or equal to `15`"
            )  # noqa: E501
        if retries is not None and retries < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for `retries`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._retries = retries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(RecurringPlanRequestPlanData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecurringPlanRequestPlanData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.recurring_response_filing import (
    RecurringResponseFiling,
)  # noqa: F401,E501


class CardBindingRecurringDataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"filing": "RecurringResponseFiling", "id": "str"}

    attribute_map = {"filing": "filing", "id": "id"}

    def __init__(self, filing=None, id=None):  # noqa: E501
        """CardBindingRecurringDataResponse - a model defined in Swagger"""  # noqa: E501

        self._filing = None
        self._id = None
        self.discriminator = None

        if filing is not None:
            self.filing = filing
        if id is not None:
            self.id = id

    @property
    def filing(self):
        """Gets the filing of this CardBindingRecurringDataResponse.  # noqa: E501

        CardPay's filing data  # noqa: E501

        :return: The filing of this CardBindingRecurringDataResponse.  # noqa: E501
        :rtype: RecurringResponseFiling
        """
        return self._filing

    @filing.setter
    def filing(self, filing):
        """Sets the filing of this CardBindingRecurringDataResponse.

        CardPay's filing data  # noqa: E501

        :param filing: The filing of this CardBindingRecurringDataResponse.  # noqa: E501
        :type: RecurringResponseFiling
        """

        self._filing = filing

    @property
    def id(self):
        """Gets the id of this CardBindingRecurringDataResponse.  # noqa: E501

        CardPay's recurring id  # noqa: E501

        :return: The id of this CardBindingRecurringDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CardBindingRecurringDataResponse.

        CardPay's recurring id  # noqa: E501

        :param id: The id of this CardBindingRecurringDataResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(CardBindingRecurringDataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardBindingRecurringDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payout_payment_data import PayoutPaymentData  # noqa: F401,E501
from cardpay.model.payout_response_card_account import (
    PayoutResponseCardAccount,
)  # noqa: F401,E501
from cardpay.model.payout_response_cryptocurrency_account import (
    PayoutResponseCryptocurrencyAccount,
)  # noqa: F401,E501
from cardpay.model.payout_response_customer import (
    PayoutResponseCustomer,
)  # noqa: F401,E501
from cardpay.model.payout_response_e_wallet_account import (
    PayoutResponseEWalletAccount,
)  # noqa: F401,E501
from cardpay.model.payout_response_payout_data import (
    PayoutResponsePayoutData,
)  # noqa: F401,E501
from cardpay.model.transaction_response_merchant_order import (
    TransactionResponseMerchantOrder,
)  # noqa: F401,E501


class PayoutResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "card_account": "PayoutResponseCardAccount",
        "cryptocurrency_account": "PayoutResponseCryptocurrencyAccount",
        "customer": "PayoutResponseCustomer",
        "ewallet_account": "PayoutResponseEWalletAccount",
        "payment_data": "PayoutPaymentData",
        "payout_data": "PayoutResponsePayoutData",
        "payment_method": "str",
        "merchant_order": "TransactionResponseMerchantOrder",
    }

    attribute_map = {
        "card_account": "card_account",
        "cryptocurrency_account": "cryptocurrency_account",
        "customer": "customer",
        "ewallet_account": "ewallet_account",
        "payment_data": "payment_data",
        "payout_data": "payout_data",
        "payment_method": "payment_method",
        "merchant_order": "merchant_order",
    }

    def __init__(
        self,
        card_account=None,
        cryptocurrency_account=None,
        customer=None,
        ewallet_account=None,
        payment_data=None,
        payout_data=None,
        payment_method=None,
        merchant_order=None,
    ):  # noqa: E501
        """PayoutResponse - a model defined in Swagger"""  # noqa: E501

        self._card_account = None
        self._cryptocurrency_account = None
        self._customer = None
        self._ewallet_account = None
        self._payment_data = None
        self._payout_data = None
        self._payment_method = None
        self._merchant_order = None
        self.discriminator = None

        if card_account is not None:
            self.card_account = card_account
        if cryptocurrency_account is not None:
            self.cryptocurrency_account = cryptocurrency_account
        if customer is not None:
            self.customer = customer
        if ewallet_account is not None:
            self.ewallet_account = ewallet_account
        if payment_data is not None:
            self.payment_data = payment_data
        self.payout_data = payout_data
        if payment_method is not None:
            self.payment_method = payment_method
        if merchant_order is not None:
            self.merchant_order = merchant_order

    @property
    def card_account(self):
        """Gets the card_account of this PayoutResponse.  # noqa: E501

        Card account data *(for BANKCARD method only)*  # noqa: E501

        :return: The card_account of this PayoutResponse.  # noqa: E501
        :rtype: PayoutResponseCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this PayoutResponse.

        Card account data *(for BANKCARD method only)*  # noqa: E501

        :param card_account: The card_account of this PayoutResponse.  # noqa: E501
        :type: PayoutResponseCardAccount
        """

        self._card_account = card_account

    @property
    def cryptocurrency_account(self):
        """Gets the cryptocurrency_account of this PayoutResponse.  # noqa: E501

        Cryptocurrency account data *(for BITCOIN method only)*  # noqa: E501

        :return: The cryptocurrency_account of this PayoutResponse.  # noqa: E501
        :rtype: PayoutResponseCryptocurrencyAccount
        """
        return self._cryptocurrency_account

    @cryptocurrency_account.setter
    def cryptocurrency_account(self, cryptocurrency_account):
        """Sets the cryptocurrency_account of this PayoutResponse.

        Cryptocurrency account data *(for BITCOIN method only)*  # noqa: E501

        :param cryptocurrency_account: The cryptocurrency_account of this PayoutResponse.  # noqa: E501
        :type: PayoutResponseCryptocurrencyAccount
        """

        self._cryptocurrency_account = cryptocurrency_account

    @property
    def customer(self):
        """Gets the customer of this PayoutResponse.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this PayoutResponse.  # noqa: E501
        :rtype: PayoutResponseCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this PayoutResponse.

        Customer data  # noqa: E501

        :param customer: The customer of this PayoutResponse.  # noqa: E501
        :type: PayoutResponseCustomer
        """

        self._customer = customer

    @property
    def ewallet_account(self):
        """Gets the ewallet_account of this PayoutResponse.  # noqa: E501

        eWallet account data *(for payout methods only)*  # noqa: E501

        :return: The ewallet_account of this PayoutResponse.  # noqa: E501
        :rtype: PayoutResponseEWalletAccount
        """
        return self._ewallet_account

    @ewallet_account.setter
    def ewallet_account(self, ewallet_account):
        """Sets the ewallet_account of this PayoutResponse.

        eWallet account data *(for payout methods only)*  # noqa: E501

        :param ewallet_account: The ewallet_account of this PayoutResponse.  # noqa: E501
        :type: PayoutResponseEWalletAccount
        """

        self._ewallet_account = ewallet_account

    @property
    def payment_data(self):
        """Gets the payment_data of this PayoutResponse.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this PayoutResponse.  # noqa: E501
        :rtype: PayoutPaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this PayoutResponse.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this PayoutResponse.  # noqa: E501
        :type: PayoutPaymentData
        """

        self._payment_data = payment_data

    @property
    def payout_data(self):
        """Gets the payout_data of this PayoutResponse.  # noqa: E501

        Payout data  # noqa: E501

        :return: The payout_data of this PayoutResponse.  # noqa: E501
        :rtype: PayoutResponsePayoutData
        """
        return self._payout_data

    @payout_data.setter
    def payout_data(self, payout_data):
        """Sets the payout_data of this PayoutResponse.

        Payout data  # noqa: E501

        :param payout_data: The payout_data of this PayoutResponse.  # noqa: E501
        :type: PayoutResponsePayoutData
        """
        if payout_data is None:
            raise ValueError(
                "Invalid value for `payout_data`, must not be `None`"
            )  # noqa: E501

        self._payout_data = payout_data

    @property
    def payment_method(self):
        """Gets the payment_method of this PayoutResponse.  # noqa: E501

        Used payment method type name from payment methods list  # noqa: E501

        :return: The payment_method of this PayoutResponse.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PayoutResponse.

        Used payment method type name from payment methods list  # noqa: E501

        :param payment_method: The payment_method of this PayoutResponse.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def merchant_order(self):
        """Gets the merchant_order of this PayoutResponse.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this PayoutResponse.  # noqa: E501
        :rtype: TransactionResponseMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this PayoutResponse.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this PayoutResponse.  # noqa: E501
        :type: TransactionResponseMerchantOrder
        """

        self._merchant_order = merchant_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.installment_data import InstallmentData  # noqa: F401,E501
from cardpay.model.payment_request_card_account import (
    PaymentRequestCardAccount,
)  # noqa: F401,E501
from cardpay.model.recurring_customer import RecurringCustomer  # noqa: F401,E501
from cardpay.model.recurring_request_merchant_order import (
    RecurringRequestMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.return_urls import ReturnUrls  # noqa: F401,E501
from cardpay.model.three_d_secure_data import ThreeDSecureData  # noqa: F401,E501


class InstallmentSubscriptionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "card_account": "PaymentRequestCardAccount",
        "customer": "RecurringCustomer",
        "merchant_order": "RecurringRequestMerchantOrder",
        "payment_method": "str",
        "recurring_data": "InstallmentData",
        "return_urls": "ReturnUrls",
        "three_d_secure": "ThreeDSecureData",
    }

    attribute_map = {
        "request": "request",
        "card_account": "card_account",
        "customer": "customer",
        "merchant_order": "merchant_order",
        "payment_method": "payment_method",
        "recurring_data": "recurring_data",
        "return_urls": "return_urls",
        "three_d_secure": "three_d_secure",
    }

    def __init__(
        self,
        request=None,
        card_account=None,
        customer=None,
        merchant_order=None,
        payment_method=None,
        recurring_data=None,
        return_urls=None,
        three_d_secure=None,
    ):  # noqa: E501
        """InstallmentSubscriptionRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._card_account = None
        self._customer = None
        self._merchant_order = None
        self._payment_method = None
        self._recurring_data = None
        self._return_urls = None
        self._three_d_secure = None
        self.discriminator = None

        self.request = request
        if card_account is not None:
            self.card_account = card_account
        if customer is not None:
            self.customer = customer
        if merchant_order is not None:
            self.merchant_order = merchant_order
        self.payment_method = payment_method
        if recurring_data is not None:
            self.recurring_data = recurring_data
        if return_urls is not None:
            self.return_urls = return_urls
        if three_d_secure is not None:
            self.three_d_secure = three_d_secure

    @property
    def request(self):
        """Gets the request of this InstallmentSubscriptionRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this InstallmentSubscriptionRequest.

        Request  # noqa: E501

        :param request: The request of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def card_account(self):
        """Gets the card_account of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The card_account of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: PaymentRequestCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this InstallmentSubscriptionRequest.


        :param card_account: The card_account of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: PaymentRequestCardAccount
        """

        self._card_account = card_account

    @property
    def customer(self):
        """Gets the customer of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The customer of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: RecurringCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this InstallmentSubscriptionRequest.


        :param customer: The customer of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: RecurringCustomer
        """

        self._customer = customer

    @property
    def merchant_order(self):
        """Gets the merchant_order of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The merchant_order of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: RecurringRequestMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this InstallmentSubscriptionRequest.


        :param merchant_order: The merchant_order of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: RecurringRequestMerchantOrder
        """

        self._merchant_order = merchant_order

    @property
    def payment_method(self):
        """Gets the payment_method of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The payment_method of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this InstallmentSubscriptionRequest.


        :param payment_method: The payment_method of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: str
        """
        if payment_method is None:
            raise ValueError(
                "Invalid value for `payment_method`, must not be `None`"
            )  # noqa: E501

        self._payment_method = payment_method

    @property
    def recurring_data(self):
        """Gets the recurring_data of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The recurring_data of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: InstallmentData
        """
        return self._recurring_data

    @recurring_data.setter
    def recurring_data(self, recurring_data):
        """Sets the recurring_data of this InstallmentSubscriptionRequest.


        :param recurring_data: The recurring_data of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: InstallmentData
        """

        self._recurring_data = recurring_data

    @property
    def return_urls(self):
        """Gets the return_urls of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The return_urls of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: ReturnUrls
        """
        return self._return_urls

    @return_urls.setter
    def return_urls(self, return_urls):
        """Sets the return_urls of this InstallmentSubscriptionRequest.


        :param return_urls: The return_urls of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: ReturnUrls
        """

        self._return_urls = return_urls

    @property
    def three_d_secure(self):
        """Gets the three_d_secure of this InstallmentSubscriptionRequest.  # noqa: E501


        :return: The three_d_secure of this InstallmentSubscriptionRequest.  # noqa: E501
        :rtype: ThreeDSecureData
        """
        return self._three_d_secure

    @three_d_secure.setter
    def three_d_secure(self, three_d_secure):
        """Sets the three_d_secure of this InstallmentSubscriptionRequest.


        :param three_d_secure: The three_d_secure of this InstallmentSubscriptionRequest.  # noqa: E501
        :type: ThreeDSecureData
        """

        self._three_d_secure = three_d_secure

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InstallmentSubscriptionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallmentSubscriptionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class RecurringsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_filing(self, **kwargs):  # noqa: E501
        """Create filing  # noqa: E501

        :param FilingRequest filing_request: Filing request parameters
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_filing_with_http_info(**kwargs)  # noqa: E501
        return data

    def create_filing_with_http_info(self, **kwargs):  # noqa: E501
        """Create filing  # noqa: E501

        :param FilingRequest filing_request: Filing request parameters
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["filing_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_filing" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "filing_request" in params:
            body_params = params["filing_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_filings",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringGatewayCreationResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def create_plan(self, recurring_plan_request, **kwargs):  # noqa: E501
        """Create recurring plan  # noqa: E501

        :param RecurringPlanRequest recurring_plan_request: recurringPlanRequest (required)
        :return: RecurringPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_plan_with_http_info(
            recurring_plan_request, **kwargs
        )  # noqa: E501
        return data

    def create_plan_with_http_info(
        self, recurring_plan_request, **kwargs
    ):  # noqa: E501
        """Create recurring plan  # noqa: E501

        :param RecurringPlanRequest recurring_plan_request: recurringPlanRequest (required)
        :return: RecurringPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_plan_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_plan" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_plan_request' is set
        if (
            "recurring_plan_request" not in params
            or params["recurring_plan_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `recurring_plan_request` when calling `create_plan`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "recurring_plan_request" in params:
            body_params = params["recurring_plan_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_plans",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringPlanResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def create_recurring(self, recurring_request, **kwargs):  # noqa: E501
        """Create recurring  # noqa: E501

        :param RecurringCreationRequest recurring_request: Recurring Request (required)
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_recurring_with_http_info(
            recurring_request, **kwargs
        )  # noqa: E501
        return data

    def create_recurring_with_http_info(
        self, recurring_request, **kwargs
    ):  # noqa: E501
        """Create recurring  # noqa: E501

        :param RecurringCreationRequest recurring_request: Recurring Request (required)
        :return: RecurringGatewayCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_recurring" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_request' is set
        if "recurring_request" not in params or params["recurring_request"] is None:
            raise ValueError(
                "Missing the required parameter `recurring_request` when calling `create_recurring`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "recurring_request" in params:
            body_params = params["recurring_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurrings",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringGatewayCreationResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_plan(self, plan_id, **kwargs):  # noqa: E501
        """Delete plan  # noqa: E501

        :param str plan_id: Plan ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.delete_plan_with_http_info(plan_id, **kwargs)  # noqa: E501
        return data

    def delete_plan_with_http_info(self, plan_id, **kwargs):  # noqa: E501
        """Delete plan  # noqa: E501

        :param str plan_id: Plan ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["plan_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_plan" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'plan_id' is set
        if "plan_id" not in params or params["plan_id"] is None:
            raise ValueError(
                "Missing the required parameter `plan_id` when calling `delete_plan`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "plan_id" in params:
            path_params["plan_id"] = params["plan_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["*/*"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_plans/{plan_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_change_status_claim(
        self, claim_id, subscription_id, **kwargs
    ):  # noqa: E501
        """Get information about Change subscription status claim  # noqa: E501

        :param str claim_id: claimId (required)
        :param str subscription_id: subscription id (required)
        :return: ChangeSubscriptionStatusClaimResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_change_status_claim_with_http_info(
            claim_id, subscription_id, **kwargs
        )  # noqa: E501
        return data

    def get_change_status_claim_with_http_info(
        self, claim_id, subscription_id, **kwargs
    ):  # noqa: E501
        """Get information about Change subscription status claim  # noqa: E501

        :param str claim_id: claimId (required)
        :param str subscription_id: subscription id (required)
        :return: ChangeSubscriptionStatusClaimResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["claim_id", "subscription_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_change_status_claim" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'claim_id' is set
        if "claim_id" not in params or params["claim_id"] is None:
            raise ValueError(
                "Missing the required parameter `claim_id` when calling `get_change_status_claim`"
            )  # noqa: E501
        # verify the required parameter 'subscription_id' is set
        if "subscription_id" not in params or params["subscription_id"] is None:
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `get_change_status_claim`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "claim_id" in params:
            path_params["claimId"] = params["claim_id"]  # noqa: E501
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_subscriptions/{subscriptionId}/change_status_claims/{claimId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ChangeSubscriptionStatusClaimResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_filing(self, filing_id, **kwargs):  # noqa: E501
        """Get filing order information  # noqa: E501

        :param str filing_id: filing order id (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_filing_with_http_info(filing_id, **kwargs)  # noqa: E501
        return data

    def get_filing_with_http_info(self, filing_id, **kwargs):  # noqa: E501
        """Get filing order information  # noqa: E501

        :param str filing_id: filing order id (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["filing_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_filing" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'filing_id' is set
        if "filing_id" not in params or params["filing_id"] is None:
            raise ValueError(
                "Missing the required parameter `filing_id` when calling `get_filing`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "filing_id" in params:
            path_params["filingId"] = params["filing_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_filings/{filingId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_plan(self, plan_id, **kwargs):  # noqa: E501
        """Get plan information  # noqa: E501

        :param str plan_id: Plan ID (required)
        :return: RecurringPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_plan_with_http_info(plan_id, **kwargs)  # noqa: E501
        return data

    def get_plan_with_http_info(self, plan_id, **kwargs):  # noqa: E501
        """Get plan information  # noqa: E501

        :param str plan_id: Plan ID (required)
        :return: RecurringPlanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["plan_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plan" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'plan_id' is set
        if "plan_id" not in params or params["plan_id"] is None:
            raise ValueError(
                "Missing the required parameter `plan_id` when calling `get_plan`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "plan_id" in params:
            path_params["plan_id"] = params["plan_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_plans/{plan_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringPlanResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_plans(self, request_id, **kwargs):  # noqa: E501
        """Get plans information  # noqa: E501

        :param str request_id: Request ID (required)
        :param int max_count: Limit number of returned plans (must be less than 10000, default is 1000)
        :param int offset: Offset (must be less than 10000)
        :param str sort_order: Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)
        :return: PlanDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_plans_with_http_info(request_id, **kwargs)  # noqa: E501
        return data

    def get_plans_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """Get plans information  # noqa: E501

        :param str request_id: Request ID (required)
        :param int max_count: Limit number of returned plans (must be less than 10000, default is 1000)
        :param int offset: Offset (must be less than 10000)
        :param str sort_order: Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)
        :return: PlanDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request_id", "max_count", "offset", "sort_order"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plans" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `get_plans`"
            )  # noqa: E501

        if "max_count" in params and params["max_count"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_plans`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_plans`, must be a value greater than or equal to `1`"
            )  # noqa: E501
        if "offset" in params and params["offset"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `offset` when calling `get_plans`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "offset" in params and params["offset"] < 0:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `offset` when calling `get_plans`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        if "sort_order" in params and not re.search(
            r"asc|desc", params["sort_order"]
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `sort_order` when calling `get_plans`, must conform to the pattern `/asc|desc/`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "max_count" in params:
            query_params.append(("max_count", params["max_count"]))  # noqa: E501
        if "offset" in params:
            query_params.append(("offset", params["offset"]))  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "sort_order" in params:
            query_params.append(("sort_order", params["sort_order"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_plans",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PlanDataList",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_recurring(self, recurring_id, **kwargs):  # noqa: E501
        """Get recurring information  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_recurring_with_http_info(recurring_id, **kwargs)  # noqa: E501
        return data

    def get_recurring_with_http_info(self, recurring_id, **kwargs):  # noqa: E501
        """Get recurring information  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :return: RecurringResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recurring" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_id' is set
        if "recurring_id" not in params or params["recurring_id"] is None:
            raise ValueError(
                "Missing the required parameter `recurring_id` when calling `get_recurring`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "recurring_id" in params:
            path_params["recurringId"] = params["recurring_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurrings/{recurringId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_recurrings(self, request_id, **kwargs):  # noqa: E501
        """Get recurring list information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param list[str] recurring_types:
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str type: Filter recurring payments by certain type (applicable to /api/recurrings endpoint only): `SCHEDULED` for scheduled recurring payments `ONECLICK` for one-click payments `INSTALLMENT` for installment payments
        :return: RecurringsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_recurrings_with_http_info(request_id, **kwargs)  # noqa: E501
        return data

    def get_recurrings_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """Get recurring list information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param list[str] recurring_types:
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str type: Filter recurring payments by certain type (applicable to /api/recurrings endpoint only): `SCHEDULED` for scheduled recurring payments `ONECLICK` for one-click payments `INSTALLMENT` for installment payments
        :return: RecurringsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "request_id",
            "currency",
            "end_time",
            "max_count",
            "merchant_order_id",
            "payment_method",
            "recurring_types",
            "sort_order",
            "start_time",
            "type",
        ]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recurrings" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `get_recurrings`"
            )  # noqa: E501

        if "request_id" in params and len(params["request_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_recurrings`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "request_id" in params and len(params["request_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_recurrings`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_recurrings`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_recurrings`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_recurrings`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) > 100:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_recurrings`, length must be less than or equal to `100`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) < 0:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_recurrings`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "sort_order" in params and not re.search(
            r"asc|desc", params["sort_order"]
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `sort_order` when calling `get_recurrings`, must conform to the pattern `/asc|desc/`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "currency" in params:
            query_params.append(("currency", params["currency"]))  # noqa: E501
        if "end_time" in params:
            query_params.append(("end_time", params["end_time"]))  # noqa: E501
        if "max_count" in params:
            query_params.append(("max_count", params["max_count"]))  # noqa: E501
        if "merchant_order_id" in params:
            query_params.append(
                ("merchant_order_id", params["merchant_order_id"])
            )  # noqa: E501
        if "payment_method" in params:
            query_params.append(
                ("payment_method", params["payment_method"])
            )  # noqa: E501
        if "recurring_types" in params:
            query_params.append(
                ("recurring_types", params["recurring_types"])
            )  # noqa: E501
            collection_formats["recurring_types"] = "multi"  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "sort_order" in params:
            query_params.append(("sort_order", params["sort_order"]))  # noqa: E501
        if "start_time" in params:
            query_params.append(("start_time", params["start_time"]))  # noqa: E501
        if "type" in params:
            query_params.append(("type", params["type"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurrings",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringsList",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_subscription(self, subscription_id, **kwargs):  # noqa: E501
        """Get subscription information  # noqa: E501

        :param str subscription_id: subscription id (required)
        :return: SubscriptionGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_subscription_with_http_info(
            subscription_id, **kwargs
        )  # noqa: E501
        return data

    def get_subscription_with_http_info(self, subscription_id, **kwargs):  # noqa: E501
        """Get subscription information  # noqa: E501

        :param str subscription_id: subscription id (required)
        :return: SubscriptionGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if "subscription_id" not in params or params["subscription_id"] is None:
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `get_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_subscriptions/{subscriptionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SubscriptionGetResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_subscriptions(self, request_id, **kwargs):  # noqa: E501
        """Get subscription information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str account_id: Merchant identifier of customer account
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned subscriptions (must be less than 10000, default is 1000)
        :param int offset: Offset (must be less than 10000)
        :param str plan_id: Id of plan. Use for searching scheduled subscriptions by plan
        :param str sort_order: Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str status: Status of subscription
        :param str type: Type of subscription. 'ONECLICK' type will be ignored.
        :return: SubscriptionList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_subscriptions_with_http_info(
            request_id, **kwargs
        )  # noqa: E501
        return data

    def get_subscriptions_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """Get subscription information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str account_id: Merchant identifier of customer account
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned subscriptions (must be less than 10000, default is 1000)
        :param int offset: Offset (must be less than 10000)
        :param str plan_id: Id of plan. Use for searching scheduled subscriptions by plan
        :param str sort_order: Sort based on order of results. 'asc' for ascending order or 'desc' for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param str status: Status of subscription
        :param str type: Type of subscription. 'ONECLICK' type will be ignored.
        :return: SubscriptionList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "request_id",
            "account_id",
            "currency",
            "end_time",
            "max_count",
            "offset",
            "plan_id",
            "sort_order",
            "start_time",
            "status",
            "type",
        ]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_subscriptions" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `get_subscriptions`"
            )  # noqa: E501

        if "request_id" in params and len(params["request_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_subscriptions`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "request_id" in params and len(params["request_id"]) < 1:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_subscriptions`, length must be greater than or equal to `1`"
            )  # noqa: E501
        if "account_id" in params and len(params["account_id"]) > 32:
            raise ValueError(
                "Invalid value for parameter `account_id` when calling `get_subscriptions`, length must be less than or equal to `32`"
            )  # noqa: E501
        if "account_id" in params and len(params["account_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `account_id` when calling `get_subscriptions`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_subscriptions`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_subscriptions`, must be a value greater than or equal to `1`"
            )  # noqa: E501
        if "offset" in params and params["offset"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `offset` when calling `get_subscriptions`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "offset" in params and params["offset"] < 0:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `offset` when calling `get_subscriptions`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        if "plan_id" in params and len(params["plan_id"]) > 32:
            raise ValueError(
                "Invalid value for parameter `plan_id` when calling `get_subscriptions`, length must be less than or equal to `32`"
            )  # noqa: E501
        if "plan_id" in params and len(params["plan_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `plan_id` when calling `get_subscriptions`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "sort_order" in params and not re.search(
            r"asc|desc", params["sort_order"]
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `sort_order` when calling `get_subscriptions`, must conform to the pattern `/asc|desc/`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "account_id" in params:
            query_params.append(("account_id", params["account_id"]))  # noqa: E501
        if "currency" in params:
            query_params.append(("currency", params["currency"]))  # noqa: E501
        if "end_time" in params:
            query_params.append(("end_time", params["end_time"]))  # noqa: E501
        if "max_count" in params:
            query_params.append(("max_count", params["max_count"]))  # noqa: E501
        if "offset" in params:
            query_params.append(("offset", params["offset"]))  # noqa: E501
        if "plan_id" in params:
            query_params.append(("plan_id", params["plan_id"]))  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "sort_order" in params:
            query_params.append(("sort_order", params["sort_order"]))  # noqa: E501
        if "start_time" in params:
            query_params.append(("start_time", params["start_time"]))  # noqa: E501
        if "status" in params:
            query_params.append(("status", params["status"]))  # noqa: E501
        if "type" in params:
            query_params.append(("type", params["type"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_subscriptions",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SubscriptionList",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_plan(self, plan_id, plan_update_request, **kwargs):  # noqa: E501
        """Update plan  # noqa: E501

        :param str plan_id: Plan ID (required)
        :param PlanUpdateRequest plan_update_request: planUpdateRequest (required)
        :return: PlanUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.update_plan_with_http_info(
            plan_id, plan_update_request, **kwargs
        )  # noqa: E501
        return data

    def update_plan_with_http_info(
        self, plan_id, plan_update_request, **kwargs
    ):  # noqa: E501
        """Update plan  # noqa: E501

        :param str plan_id: Plan ID (required)
        :param PlanUpdateRequest plan_update_request: planUpdateRequest (required)
        :return: PlanUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["plan_id", "plan_update_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_plan" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'plan_id' is set
        if "plan_id" not in params or params["plan_id"] is None:
            raise ValueError(
                "Missing the required parameter `plan_id` when calling `update_plan`"
            )  # noqa: E501
        # verify the required parameter 'plan_update_request' is set
        if "plan_update_request" not in params or params["plan_update_request"] is None:
            raise ValueError(
                "Missing the required parameter `plan_update_request` when calling `update_plan`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "plan_id" in params:
            path_params["plan_id"] = params["plan_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "plan_update_request" in params:
            body_params = params["plan_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_plans/{plan_id}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PlanUpdateResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_recurring(
        self, recurring_id, recurring_patch_request, **kwargs
    ):  # noqa: E501
        """Update recurring  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :param RecurringPatchRequest recurring_patch_request: recurringPatchRequest (required)
        :return: RecurringUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.update_recurring_with_http_info(
            recurring_id, recurring_patch_request, **kwargs
        )  # noqa: E501
        return data

    def update_recurring_with_http_info(
        self, recurring_id, recurring_patch_request, **kwargs
    ):  # noqa: E501
        """Update recurring  # noqa: E501

        :param str recurring_id: Recurring ID (required)
        :param RecurringPatchRequest recurring_patch_request: recurringPatchRequest (required)
        :return: RecurringUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["recurring_id", "recurring_patch_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_recurring" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'recurring_id' is set
        if "recurring_id" not in params or params["recurring_id"] is None:
            raise ValueError(
                "Missing the required parameter `recurring_id` when calling `update_recurring`"
            )  # noqa: E501
        # verify the required parameter 'recurring_patch_request' is set
        if (
            "recurring_patch_request" not in params
            or params["recurring_patch_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `recurring_patch_request` when calling `update_recurring`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "recurring_id" in params:
            path_params["recurringId"] = params["recurring_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "recurring_patch_request" in params:
            body_params = params["recurring_patch_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurrings/{recurringId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RecurringUpdateResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_subscription(
        self, subscription_id, subscription_update_request, **kwargs
    ):  # noqa: E501
        """Update subscription  # noqa: E501

        :param str subscription_id: Subscription ID (required)
        :param SubscriptionUpdateRequest subscription_update_request: subscriptionUpdateRequest (required)
        :return: SubscriptionUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.update_subscription_with_http_info(
            subscription_id, subscription_update_request, **kwargs
        )  # noqa: E501
        return data

    def update_subscription_with_http_info(
        self, subscription_id, subscription_update_request, **kwargs
    ):  # noqa: E501
        """Update subscription  # noqa: E501

        :param str subscription_id: Subscription ID (required)
        :param SubscriptionUpdateRequest subscription_update_request: subscriptionUpdateRequest (required)
        :return: SubscriptionUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id", "subscription_update_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if "subscription_id" not in params or params["subscription_id"] is None:
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `update_subscription`"
            )  # noqa: E501
        # verify the required parameter 'subscription_update_request' is set
        if (
            "subscription_update_request" not in params
            or params["subscription_update_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `subscription_update_request` when calling `update_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "subscription_update_request" in params:
            body_params = params["subscription_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/recurring_subscriptions/{subscriptionId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SubscriptionUpdateResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cardpay.api_client import ApiClient


class PayoutsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_payout(self, payout_request, **kwargs):  # noqa: E501
        """Create payout  # noqa: E501

        :param PayoutRequest payout_request: payoutRequest (required)
        :return: PayoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.create_payout_with_http_info(
            payout_request, **kwargs
        )  # noqa: E501
        return data

    def create_payout_with_http_info(self, payout_request, **kwargs):  # noqa: E501
        """Create payout  # noqa: E501

        :param PayoutRequest payout_request: payoutRequest (required)
        :return: PayoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["payout_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_payout" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'payout_request' is set
        if "payout_request" not in params or params["payout_request"] is None:
            raise ValueError(
                "Missing the required parameter `payout_request` when calling `create_payout`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "payout_request" in params:
            body_params = params["payout_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/payouts",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PayoutResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_payout(self, payout_id, **kwargs):  # noqa: E501
        """Read payout information  # noqa: E501

        :param str payout_id: Payout ID (required)
        :return: PayoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_payout_with_http_info(payout_id, **kwargs)  # noqa: E501
        return data

    def get_payout_with_http_info(self, payout_id, **kwargs):  # noqa: E501
        """Read payout information  # noqa: E501

        :param str payout_id: Payout ID (required)
        :return: PayoutResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["payout_id"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_payout" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'payout_id' is set
        if "payout_id" not in params or params["payout_id"] is None:
            raise ValueError(
                "Missing the required parameter `payout_id` when calling `get_payout`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "payout_id" in params:
            path_params["payoutId"] = params["payout_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/payouts/{payoutId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PayoutResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_payouts(self, request_id, **kwargs):  # noqa: E501
        """Get payouts information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :return: PayoutsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.get_payouts_with_http_info(request_id, **kwargs)  # noqa: E501
        return data

    def get_payouts_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """Get payouts information  # noqa: E501

        :param str request_id: Request ID (required)
        :param str currency: [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code of transactions currency
        :param datetime end_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period ends (not inclusive), UTC time, must be less than 7 days after 'start_time', default is current time (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :param int max_count: Limit number of returned transactions (must be less than 10000, default is 1000)
        :param str merchant_order_id: Merchant order number from the merchant system
        :param str payment_method: Used payment method type name from payment methods list
        :param str sort_order: Sort based on order of results. `asc` for ascending order or `desc` for descending order (default value)
        :param datetime start_time: Date and time up to milliseconds (in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format) when requested period starts (inclusive), UTC time, default is 24 hours before 'end_time' (format: yyyy-MM-dd'T'HH:mm:ss'Z')
        :return: PayoutsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "request_id",
            "currency",
            "end_time",
            "max_count",
            "merchant_order_id",
            "payment_method",
            "sort_order",
            "start_time",
        ]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_payouts" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request_id' is set
        if "request_id" not in params or params["request_id"] is None:
            raise ValueError(
                "Missing the required parameter `request_id` when calling `get_payouts`"
            )  # noqa: E501

        if "request_id" in params and len(params["request_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_payouts`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "request_id" in params and len(params["request_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `request_id` when calling `get_payouts`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "max_count" in params and params["max_count"] > 10000:  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `max_count` when calling `get_payouts`, must be a value less than or equal to `10000`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) > 50:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_payouts`, length must be less than or equal to `50`"
            )  # noqa: E501
        if "merchant_order_id" in params and len(params["merchant_order_id"]) < 0:
            raise ValueError(
                "Invalid value for parameter `merchant_order_id` when calling `get_payouts`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) > 100:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_payouts`, length must be less than or equal to `100`"
            )  # noqa: E501
        if "payment_method" in params and len(params["payment_method"]) < 0:
            raise ValueError(
                "Invalid value for parameter `payment_method` when calling `get_payouts`, length must be greater than or equal to `0`"
            )  # noqa: E501
        if "sort_order" in params and not re.search(
            r"asc|desc", params["sort_order"]
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for parameter `sort_order` when calling `get_payouts`, must conform to the pattern `/asc|desc/`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if "currency" in params:
            query_params.append(("currency", params["currency"]))  # noqa: E501
        if "end_time" in params:
            query_params.append(("end_time", params["end_time"]))  # noqa: E501
        if "max_count" in params:
            query_params.append(("max_count", params["max_count"]))  # noqa: E501
        if "merchant_order_id" in params:
            query_params.append(
                ("merchant_order_id", params["merchant_order_id"])
            )  # noqa: E501
        if "payment_method" in params:
            query_params.append(
                ("payment_method", params["payment_method"])
            )  # noqa: E501
        if "request_id" in params:
            query_params.append(("request_id", params["request_id"]))  # noqa: E501
        if "sort_order" in params:
            query_params.append(("sort_order", params["sort_order"]))  # noqa: E501
        if "start_time" in params:
            query_params.append(("start_time", params["start_time"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/payouts",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PayoutsList",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def update_payout(self, payout_id, payout_update_request, **kwargs):  # noqa: E501
        """Update payout  # noqa: E501

        :param str payout_id: Payout ID (required)
        :param PayoutUpdateRequest payout_update_request: payoutUpdateRequest (required)
        :return: PayoutUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True

        (data) = self.update_payout_with_http_info(
            payout_id, payout_update_request, **kwargs
        )  # noqa: E501
        return data

    def update_payout_with_http_info(
        self, payout_id, payout_update_request, **kwargs
    ):  # noqa: E501
        """Update payout  # noqa: E501

        :param str payout_id: Payout ID (required)
        :param PayoutUpdateRequest payout_update_request: payoutUpdateRequest (required)
        :return: PayoutUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["payout_id", "payout_update_request"]  # noqa: E501
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_payout" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'payout_id' is set
        if "payout_id" not in params or params["payout_id"] is None:
            raise ValueError(
                "Missing the required parameter `payout_id` when calling `update_payout`"
            )  # noqa: E501
        # verify the required parameter 'payout_update_request' is set
        if (
            "payout_update_request" not in params
            or params["payout_update_request"] is None
        ):
            raise ValueError(
                "Missing the required parameter `payout_update_request` when calling `update_payout`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "payout_id" in params:
            path_params["payoutId"] = params["payout_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "payout_update_request" in params:
            body_params = params["payout_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        return self.api_client.call_api(
            "/api/payouts/{payoutId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PayoutUpdateResponse",  # noqa: E501
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PayoutRequestLivingAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "address": "str",
        "city": "str",
        "country": "str",
        "state": "str",
        "zip": "str",
    }

    attribute_map = {
        "address": "address",
        "city": "city",
        "country": "country",
        "state": "state",
        "zip": "zip",
    }

    def __init__(
        self, address=None, city=None, country=None, state=None, zip=None
    ):  # noqa: E501
        """PayoutRequestLivingAddress - a model defined in Swagger"""  # noqa: E501

        self._address = None
        self._city = None
        self._country = None
        self._state = None
        self._zip = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if state is not None:
            self.state = state
        if zip is not None:
            self.zip = zip

    @property
    def address(self):
        """Gets the address of this PayoutRequestLivingAddress.  # noqa: E501

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :return: The address of this PayoutRequestLivingAddress.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this PayoutRequestLivingAddress.

        Customer address *(mandatory for 'Latin America' methods only)* For 'Latin America' is required for methods where country = CO  # noqa: E501

        :param address: The address of this PayoutRequestLivingAddress.  # noqa: E501
        :type: str
        """
        if address is not None and len(address) > 100:
            raise ValueError(
                "Invalid value for `address`, length must be less than or equal to `100`"
            )  # noqa: E501
        if address is not None and len(address) < 0:
            raise ValueError(
                "Invalid value for `address`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._address = address

    @property
    def city(self):
        """Gets the city of this PayoutRequestLivingAddress.  # noqa: E501

        Customer city.  # noqa: E501

        :return: The city of this PayoutRequestLivingAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this PayoutRequestLivingAddress.

        Customer city.  # noqa: E501

        :param city: The city of this PayoutRequestLivingAddress.  # noqa: E501
        :type: str
        """
        if city is not None and len(city) > 20:
            raise ValueError(
                "Invalid value for `city`, length must be less than or equal to `20`"
            )  # noqa: E501
        if city is not None and len(city) < 0:
            raise ValueError(
                "Invalid value for `city`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._city = city

    @property
    def country(self):
        """Gets the country of this PayoutRequestLivingAddress.  # noqa: E501

        ISO 3166-1 code of country: 2 or 3 latin letters or numeric code.  # noqa: E501

        :return: The country of this PayoutRequestLivingAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this PayoutRequestLivingAddress.

        ISO 3166-1 code of country: 2 or 3 latin letters or numeric code.  # noqa: E501

        :param country: The country of this PayoutRequestLivingAddress.  # noqa: E501
        :type: str
        """
        if country is not None and len(country) > 3:
            raise ValueError(
                "Invalid value for `country`, length must be less than or equal to `3`"
            )  # noqa: E501
        if country is not None and len(country) < 2:
            raise ValueError(
                "Invalid value for `country`, length must be greater than or equal to `2`"
            )  # noqa: E501

        self._country = country

    @property
    def state(self):
        """Gets the state of this PayoutRequestLivingAddress.  # noqa: E501

        Living state or province.  # noqa: E501

        :return: The state of this PayoutRequestLivingAddress.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PayoutRequestLivingAddress.

        Living state or province.  # noqa: E501

        :param state: The state of this PayoutRequestLivingAddress.  # noqa: E501
        :type: str
        """
        if state is not None and len(state) > 20:
            raise ValueError(
                "Invalid value for `state`, length must be less than or equal to `20`"
            )  # noqa: E501
        if state is not None and len(state) < 0:
            raise ValueError(
                "Invalid value for `state`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._state = state

    @property
    def zip(self):
        """Gets the zip of this PayoutRequestLivingAddress.  # noqa: E501

        Customer postal code  # noqa: E501

        :return: The zip of this PayoutRequestLivingAddress.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this PayoutRequestLivingAddress.

        Customer postal code  # noqa: E501

        :param zip: The zip of this PayoutRequestLivingAddress.  # noqa: E501
        :type: str
        """
        if zip is not None and len(zip) > 17:
            raise ValueError(
                "Invalid value for `zip`, length must be less than or equal to `17`"
            )  # noqa: E501
        if zip is not None and len(zip) < 0:
            raise ValueError(
                "Invalid value for `zip`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutRequestLivingAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutRequestLivingAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.mobile_payment_merchant_order import (
    MobilePaymentMerchantOrder,
)  # noqa: F401,E501
from cardpay.model.payment_request_card_account import (
    PaymentRequestCardAccount,
)  # noqa: F401,E501
from cardpay.model.payment_request_customer import (
    PaymentRequestCustomer,
)  # noqa: F401,E501
from cardpay.model.payment_request_payment_data import (
    PaymentRequestPaymentData,
)  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.return_urls import ReturnUrls  # noqa: F401,E501


class MobilePaymentRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "card_account": "PaymentRequestCardAccount",
        "customer": "PaymentRequestCustomer",
        "merchant_order": "MobilePaymentMerchantOrder",
        "mobile_token": "str",
        "payment_data": "PaymentRequestPaymentData",
        "payment_method": "str",
        "return_urls": "ReturnUrls",
    }

    attribute_map = {
        "request": "request",
        "card_account": "card_account",
        "customer": "customer",
        "merchant_order": "merchant_order",
        "mobile_token": "mobile_token",
        "payment_data": "payment_data",
        "payment_method": "payment_method",
        "return_urls": "return_urls",
    }

    def __init__(
        self,
        request=None,
        card_account=None,
        customer=None,
        merchant_order=None,
        mobile_token=None,
        payment_data=None,
        payment_method=None,
        return_urls=None,
    ):  # noqa: E501
        """MobilePaymentRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._card_account = None
        self._customer = None
        self._merchant_order = None
        self._mobile_token = None
        self._payment_data = None
        self._payment_method = None
        self._return_urls = None
        self.discriminator = None

        self.request = request
        self.card_account = card_account
        self.customer = customer
        self.merchant_order = merchant_order
        if mobile_token is not None:
            self.mobile_token = mobile_token
        self.payment_data = payment_data
        if payment_method is not None:
            self.payment_method = payment_method
        if return_urls is not None:
            self.return_urls = return_urls

    @property
    def request(self):
        """Gets the request of this MobilePaymentRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this MobilePaymentRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this MobilePaymentRequest.

        Request  # noqa: E501

        :param request: The request of this MobilePaymentRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def card_account(self):
        """Gets the card_account of this MobilePaymentRequest.  # noqa: E501

        Information about card *(for BANKCARD payment method only)*  # noqa: E501

        :return: The card_account of this MobilePaymentRequest.  # noqa: E501
        :rtype: PaymentRequestCardAccount
        """
        return self._card_account

    @card_account.setter
    def card_account(self, card_account):
        """Sets the card_account of this MobilePaymentRequest.

        Information about card *(for BANKCARD payment method only)*  # noqa: E501

        :param card_account: The card_account of this MobilePaymentRequest.  # noqa: E501
        :type: PaymentRequestCardAccount
        """
        if card_account is None:
            raise ValueError(
                "Invalid value for `card_account`, must not be `None`"
            )  # noqa: E501

        self._card_account = card_account

    @property
    def customer(self):
        """Gets the customer of this MobilePaymentRequest.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this MobilePaymentRequest.  # noqa: E501
        :rtype: PaymentRequestCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this MobilePaymentRequest.

        Customer data  # noqa: E501

        :param customer: The customer of this MobilePaymentRequest.  # noqa: E501
        :type: PaymentRequestCustomer
        """
        if customer is None:
            raise ValueError(
                "Invalid value for `customer`, must not be `None`"
            )  # noqa: E501

        self._customer = customer

    @property
    def merchant_order(self):
        """Gets the merchant_order of this MobilePaymentRequest.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this MobilePaymentRequest.  # noqa: E501
        :rtype: MobilePaymentMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this MobilePaymentRequest.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this MobilePaymentRequest.  # noqa: E501
        :type: MobilePaymentMerchantOrder
        """
        if merchant_order is None:
            raise ValueError(
                "Invalid value for `merchant_order`, must not be `None`"
            )  # noqa: E501

        self._merchant_order = merchant_order

    @property
    def mobile_token(self):
        """Gets the mobile_token of this MobilePaymentRequest.  # noqa: E501

        Unique identifier, max 128 symbols  # noqa: E501

        :return: The mobile_token of this MobilePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._mobile_token

    @mobile_token.setter
    def mobile_token(self, mobile_token):
        """Sets the mobile_token of this MobilePaymentRequest.

        Unique identifier, max 128 symbols  # noqa: E501

        :param mobile_token: The mobile_token of this MobilePaymentRequest.  # noqa: E501
        :type: str
        """

        self._mobile_token = mobile_token

    @property
    def payment_data(self):
        """Gets the payment_data of this MobilePaymentRequest.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this MobilePaymentRequest.  # noqa: E501
        :rtype: PaymentRequestPaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this MobilePaymentRequest.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this MobilePaymentRequest.  # noqa: E501
        :type: PaymentRequestPaymentData
        """
        if payment_data is None:
            raise ValueError(
                "Invalid value for `payment_data`, must not be `None`"
            )  # noqa: E501

        self._payment_data = payment_data

    @property
    def payment_method(self):
        """Gets the payment_method of this MobilePaymentRequest.  # noqa: E501

        Used payment method type name from payment methods list  # noqa: E501

        :return: The payment_method of this MobilePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this MobilePaymentRequest.

        Used payment method type name from payment methods list  # noqa: E501

        :param payment_method: The payment_method of this MobilePaymentRequest.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def return_urls(self):
        """Gets the return_urls of this MobilePaymentRequest.  # noqa: E501

        Return URLs are the URLs where Customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment page mode and redirected automatically in Gateway mode  # noqa: E501

        :return: The return_urls of this MobilePaymentRequest.  # noqa: E501
        :rtype: ReturnUrls
        """
        return self._return_urls

    @return_urls.setter
    def return_urls(self, return_urls):
        """Sets the return_urls of this MobilePaymentRequest.

        Return URLs are the URLs where Customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment page mode and redirected automatically in Gateway mode  # noqa: E501

        :param return_urls: The return_urls of this MobilePaymentRequest.  # noqa: E501
        :type: ReturnUrls
        """

        self._return_urls = return_urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(MobilePaymentRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobilePaymentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.billing_address import BillingAddress  # noqa: F401,E501
from cardpay.model.payout_request_card import PayoutRequestCard  # noqa: F401,E501


class PayoutRequestCardAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "billing_address": "BillingAddress",
        "card": "PayoutRequestCard",
        "empty": "bool",
        "recipient_info": "str",
        "token": "str",
    }

    attribute_map = {
        "billing_address": "billing_address",
        "card": "card",
        "empty": "empty",
        "recipient_info": "recipient_info",
        "token": "token",
    }

    def __init__(
        self,
        billing_address=None,
        card=None,
        empty=None,
        recipient_info=None,
        token=None,
    ):  # noqa: E501
        """PayoutRequestCardAccount - a model defined in Swagger"""  # noqa: E501

        self._billing_address = None
        self._card = None
        self._empty = None
        self._recipient_info = None
        self._token = None
        self.discriminator = None

        if billing_address is not None:
            self.billing_address = billing_address
        if card is not None:
            self.card = card
        if empty is not None:
            self.empty = empty
        if recipient_info is not None:
            self.recipient_info = recipient_info
        if token is not None:
            self.token = token

    @property
    def billing_address(self):
        """Gets the billing_address of this PayoutRequestCardAccount.  # noqa: E501

        Address for billing  # noqa: E501

        :return: The billing_address of this PayoutRequestCardAccount.  # noqa: E501
        :rtype: BillingAddress
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this PayoutRequestCardAccount.

        Address for billing  # noqa: E501

        :param billing_address: The billing_address of this PayoutRequestCardAccount.  # noqa: E501
        :type: BillingAddress
        """

        self._billing_address = billing_address

    @property
    def card(self):
        """Gets the card of this PayoutRequestCardAccount.  # noqa: E501

        Represents a payout card data. Card section shouldn't be present if element `token` was presented.  # noqa: E501

        :return: The card of this PayoutRequestCardAccount.  # noqa: E501
        :rtype: PayoutRequestCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this PayoutRequestCardAccount.

        Represents a payout card data. Card section shouldn't be present if element `token` was presented.  # noqa: E501

        :param card: The card of this PayoutRequestCardAccount.  # noqa: E501
        :type: PayoutRequestCard
        """

        self._card = card

    @property
    def empty(self):
        """Gets the empty of this PayoutRequestCardAccount.  # noqa: E501


        :return: The empty of this PayoutRequestCardAccount.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this PayoutRequestCardAccount.


        :param empty: The empty of this PayoutRequestCardAccount.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def recipient_info(self):
        """Gets the recipient_info of this PayoutRequestCardAccount.  # noqa: E501

        Property `recipient_info` may be required by Bank. In most cases it's Cardholder's name, contact CardPay manager for requirements. It must be omitted when property `token` is presented  # noqa: E501

        :return: The recipient_info of this PayoutRequestCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._recipient_info

    @recipient_info.setter
    def recipient_info(self, recipient_info):
        """Sets the recipient_info of this PayoutRequestCardAccount.

        Property `recipient_info` may be required by Bank. In most cases it's Cardholder's name, contact CardPay manager for requirements. It must be omitted when property `token` is presented  # noqa: E501

        :param recipient_info: The recipient_info of this PayoutRequestCardAccount.  # noqa: E501
        :type: str
        """
        if recipient_info is not None and len(recipient_info) > 500:
            raise ValueError(
                "Invalid value for `recipient_info`, length must be less than or equal to `500`"
            )  # noqa: E501
        if recipient_info is not None and len(recipient_info) < 0:
            raise ValueError(
                "Invalid value for `recipient_info`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._recipient_info = recipient_info

    @property
    def token(self):
        """Gets the token of this PayoutRequestCardAccount.  # noqa: E501

        Card token value, used instead of a card data  # noqa: E501

        :return: The token of this PayoutRequestCardAccount.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this PayoutRequestCardAccount.

        Card token value, used instead of a card data  # noqa: E501

        :param token: The token of this PayoutRequestCardAccount.  # noqa: E501
        :type: str
        """
        if token is not None and len(token) > 36:
            raise ValueError(
                "Invalid value for `token`, length must be less than or equal to `36`"
            )  # noqa: E501
        if token is not None and len(token) < 0:
            raise ValueError(
                "Invalid value for `token`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._token = token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutRequestCardAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutRequestCardAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
